@@ -1,5 +1,5 @@
 /*  Audacious - Cross-platform multimedia player
- *  Copyright (C) 2005-2008  Audacious development team.
+ *  Copyright (C) 2005-2010  Audacious development team.
  *
  *  Based on BMP:
  *  Copyright (C) 2003-2004  BMP development team.
@@ -23,19 +23,21 @@
  *  Audacious or using our public API to be a derived work.
  */
 
+#include <glib.h>
+#include <libaudcore/hook.h>
+
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
 
 #include "audconfig.h"
-
+#include "configdb.h"
 #include "effect.h"
 #include "general.h"
+#include "output.h"
 #include "playback.h"
-#include "playlist-new.h"
-#include "playlist-utils.h"
 #include "pluginenum.h"
-#include "plugin-registry.h"
+#include "plugins.h"
 #include "util.h"
 #include "visualization.h"
 
@@ -57,10 +59,6 @@ AudConfig aud_default_config = {
     .equalizer_bands = {0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
     .filesel_path = NULL,
     .playlist_path = NULL,
-    .enabled_gplugins = NULL,          /* enabled general plugins */
-    .enabled_vplugins = NULL,          /* enabled visualization plugins */
-    .enabled_eplugins = NULL,          /* enabled effect plugins */
-    .enabled_dplugins = NULL,          /* enabled discovery plugins */
     .eqpreset_default_file = NULL,
     .eqpreset_extension = NULL,
     .url_history = NULL,
@@ -91,9 +89,19 @@ AudConfig aud_default_config = {
     .replay_gain_preamp = 0,
     .default_gain = 0,
     .sw_volume_left = 100, .sw_volume_right = 100,
-    .clear_playlist = FALSE,
+    .clear_playlist = TRUE,
     .output_path = NULL,
     .output_number = -1,
+    .iface_path = NULL,
+    .iface_number = -1,
+
+    /* libaudgui stuff */
+    .no_confirm_playlist_delete = FALSE,
+    .playlist_manager_x = 0,
+    .playlist_manager_y = 0,
+    .playlist_manager_width = 0,
+    .playlist_manager_height = 0,
+    .playlist_manager_close_on_activate = FALSE,
 };
 
 typedef struct aud_cfg_boolent_t {
@@ -138,7 +146,10 @@ static aud_cfg_boolent aud_boolents[] = {
     {"enable_clipping_prevention", &cfg.enable_clipping_prevention, TRUE},
     {"replay_gain_track", &cfg.replay_gain_track, TRUE},
     {"replay_gain_album", &cfg.replay_gain_album, TRUE},
-    {"clear_playlist", & cfg.clear_playlist, TRUE},
+    {"clear_playlist", &cfg.clear_playlist, TRUE},
+    {"no_confirm_playlist_delete", &cfg.no_confirm_playlist_delete, TRUE},
+    {"playlist_manager_close_on_activate",
+     & cfg.playlist_manager_close_on_activate, TRUE},
 };
 
 static gint ncfgbent = G_N_ELEMENTS(aud_boolents);
@@ -155,6 +166,11 @@ static aud_cfg_nument aud_numents[] = {
     {"sw_volume_left", & cfg.sw_volume_left, TRUE},
     {"sw_volume_right", & cfg.sw_volume_right, TRUE},
     {"output_number", & cfg.output_number, TRUE},
+    {"iface_number", & cfg.iface_number, TRUE},
+    {"playlist_manager_x", & cfg.playlist_manager_x, TRUE},
+    {"playlist_manager_y", & cfg.playlist_manager_y, TRUE},
+    {"playlist_manager_width", & cfg.playlist_manager_width, TRUE},
+    {"playlist_manager_height", & cfg.playlist_manager_height, TRUE},
 };
 
 static gint ncfgient = G_N_ELEMENTS(aud_numents);
@@ -162,9 +178,6 @@ static gint ncfgient = G_N_ELEMENTS(aud_numents);
 static aud_cfg_strent aud_strents[] = {
     {"eqpreset_default_file", &cfg.eqpreset_default_file, TRUE},
     {"eqpreset_extension", &cfg.eqpreset_extension, TRUE},
-    {"enabled_gplugins", &cfg.enabled_gplugins, FALSE},
-    {"enabled_vplugins", &cfg.enabled_vplugins, FALSE},
-    {"enabled_eplugins", &cfg.enabled_eplugins, FALSE},
     {"filesel_path", &cfg.filesel_path, FALSE},
     {"playlist_path", &cfg.playlist_path, FALSE},
     {"generic_title_format", &cfg.gentitle_format, TRUE},
@@ -173,138 +186,11 @@ static aud_cfg_strent aud_strents[] = {
     {"cover_name_include", &cfg.cover_name_include, TRUE},
     {"cover_name_exclude", &cfg.cover_name_exclude, TRUE},
     {"output_path", & cfg.output_path, TRUE},
+    {"iface_path", & cfg.iface_path, TRUE},
 };
 
 static gint ncfgsent = G_N_ELEMENTS(aud_strents);
 
-
-static gboolean
-save_extra_playlist(const gchar * path, const gchar * basename,
-        gpointer savedlist)
-{
-    gint playlists, playlist;
-    GList **saved;
-    int found;
-    const gchar * filename;
-
-    playlists = playlist_count ();
-    saved = (GList **) savedlist;
-
-    found = 0;
-
-    for (playlist = 0; playlist < playlists; playlist ++)
-    {
-        if (g_list_find (* saved, GINT_TO_POINTER (playlist)) != NULL)
-            continue;
-
-        filename = playlist_get_filename (playlist);
-
-        if (filename == NULL)
-            continue;
-
-        if (strcmp(filename, path) == 0) {
-            /* Save playlist */
-            playlist_save(playlist, path);
-            * saved = g_list_prepend (* saved, GINT_TO_POINTER (playlist));
-            found = 1;
-            break;
-        }
-    }
-
-    if(!found) {
-        /* Remove playlist */
-        unlink(path);
-    }
-
-    return FALSE; /* process other playlists */
-}
-
-static void
-save_other_playlists(GList *saved)
-{
-    gint playlists, playlist;
-    gchar * pos, * ext, * basename, * newbasename, * new_filename;
-    const gchar * filename;
-    int i, num, isdigits;
-
-    playlists = playlist_count ();
-
-    for (playlist = 0; playlist < playlists; playlist ++)
-    {
-        if (g_list_find (saved, GINT_TO_POINTER (playlist)) != NULL)
-            continue;
-
-        filename = playlist_get_filename (playlist);
-
-        if (filename == NULL || g_file_test (filename, G_FILE_TEST_IS_DIR))
-        {
-            /* default basename */
-#ifdef HAVE_XSPF_PLAYLIST
-            basename = g_strdup("playlist_01.xspf");
-#else
-            basename = g_strdup("playlist_01.m3u");
-#endif
-        } else {
-            basename = g_path_get_basename(filename);
-        }
-
-        if ((pos = strrchr(basename, '.'))) {
-            *pos = '\0';
-        }
-#ifdef HAVE_XSPF_PLAYLIST
-        ext = ".xspf";
-#else
-        ext = ".m3u";
-#endif
-        num = -1;
-        if ((pos = strrchr(basename, '_'))) {
-            isdigits = 0;
-            for (i=1; pos[i]; i++) {
-                if (!g_ascii_isdigit(pos[i])) {
-                    isdigits = 0;
-                    break;
-                }
-                isdigits = 1;
-            }
-            if (isdigits) {
-                num = atoi(pos+1) + 1;
-                *pos = '\0';
-            }
-        }
-        /* attempt to generate unique filename */
-        new_filename = NULL;
-
-        do {
-            g_free (new_filename);
-
-            if (num < 0) {
-                /* try saving without number first */
-                newbasename = g_strdup_printf("%s%s", basename, ext);
-                num = 1;
-            } else {
-                newbasename = g_strdup_printf("%s_%02d%s", basename, num, ext);
-                num++;
-                if (num < 0) {
-                    g_warning("Playlist number in filename overflowed."
-                            " Not saving playlist.\n");
-                    goto cleanup;
-                }
-            }
-
-            new_filename = g_build_filename (aud_paths[BMP_PATH_PLAYLISTS_DIR],
-                    newbasename, NULL);
-            g_free(newbasename);
-        }
-        while (g_file_test (new_filename, G_FILE_TEST_EXISTS));
-
-        playlist_save (playlist, new_filename);
-cleanup:
-        g_free (new_filename);
-        g_free(basename);
-    }
-}
-
-
 void
 aud_config_free(void)
 {
@@ -397,34 +283,16 @@ aud_config_load(void)
         cfg.cover_name_exclude = g_strdup("back");
 }
 
-void save_all_playlists (void)
-{
-    GList * saved;
-
-    /* Main playlist becomes #0 at load, so save #0 as main. -jlindgren */
-    if (! playlist_save (0, aud_paths[BMP_PATH_PLAYLIST_FILE]))
-        g_warning ("Could not save main playlist\n");
-
-    /* Save extra playlists that were loaded from PLAYLISTS_DIR  */
-    saved = g_list_append (NULL, GINT_TO_POINTER (0));
-
-    if (! dir_foreach (aud_paths[BMP_PATH_PLAYLISTS_DIR], save_extra_playlist,
-     & saved, NULL))
-        g_warning ("Could not save extra playlists\n");
-
-    /* Save other playlists to PLAYLISTS_DIR */
-    save_other_playlists (saved);
-    g_list_free (saved);
-}
-
 static void save_output_path (void)
 {
     const gchar * path = NULL;
     gint type, number = -1;
 
     if (current_output_plugin != NULL)
-        plugin_get_path (current_output_plugin, & path, & type, & number);
+        plugin_get_path (plugin_by_header (current_output_plugin), & path,
+         & type, & number);
 
+    g_free (cfg.output_path);
     cfg.output_path = (path != NULL) ? g_strdup (path) : NULL;
     cfg.output_number = number;
 }
@@ -437,6 +305,8 @@ aud_config_save(void)
     gint i;
     mcs_handle_t *db;
 
+    hook_call ("config save", NULL);
+
     cfg.resume_state = playback_get_playing () ? (playback_get_paused () ? 2 :
      1) : 0;
     cfg.resume_playback_on_startup_time = playback_get_playing () ?
@@ -458,8 +328,6 @@ aud_config_save(void)
                                aud_numents[i].ie_vname,
                                *aud_numents[i].ie_vloc);
 
-    hook_call("config save", db);
-
     for (i = 0; i < ncfgsent; ++i) {
         if (aud_strents[i].se_wrt)
             cfg_db_set_string(db, NULL,
@@ -479,30 +347,6 @@ aud_config_save(void)
         g_free(str);
     }
 
-    str = general_stringify_enabled_list();
-    if (str) {
-        cfg_db_set_string(db, NULL, "enabled_gplugins", str);
-        g_free(str);
-    }
-    else
-        cfg_db_unset_key(db, NULL, "enabled_gplugins");
-
-    str = vis_stringify_enabled_list();
-    if (str) {
-        cfg_db_set_string(db, NULL, "enabled_vplugins", str);
-        g_free(str);
-    }
-    else
-        cfg_db_unset_key(db, NULL, "enabled_vplugins");
-
-    str = effect_stringify_enabled_list();
-    if (str) {
-        cfg_db_set_string(db, NULL, "enabled_eplugins", str);
-        g_free(str);
-    }
-    else
-        cfg_db_unset_key(db, NULL, "enabled_eplugins");
-
     if (cfg.filesel_path)
         cfg_db_set_string(db, NULL, "filesel_path", cfg.filesel_path);
 
@@ -519,6 +363,4 @@ aud_config_save(void)
     }
 
     cfg_db_close(db);
-
-    save_all_playlists ();
 }
