@@ -19,19 +19,16 @@
  * Audacious or using our public API to be a derived work.
  */
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
-
 #include <glib.h>
-#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <string.h>
 
-#include "ui_fileinfopopup.h"
-#include "main.h"
-#include "playlist.h"
-#include "playback.h"
+#include <libaudcore/audstrings.h>
+
+#include "audconfig.h"
+#include "config.h"
+#include "i18n.h"
+#include "misc.h"
 
 static gboolean
 has_front_cover_extension(const gchar *name)
@@ -118,15 +115,14 @@ is_file_image(const gchar *imgfile, const gchar *file_name)
 	}
 }
 
-gchar*
-fileinfo_recursive_get_image(const gchar* path,
-	const gchar* file_name, gint depth)
+static gchar * fileinfo_recursive_get_image (const gchar * path, const gchar *
+ file_name, gint depth)
 {
 	GDir *d;
 
 	if (cfg.recurse_for_cover && depth > cfg.recurse_for_cover_depth)
 		return NULL;
-	
+
 	d = g_dir_open(path, 0, NULL);
 
 	if (d) {
@@ -134,7 +130,7 @@ fileinfo_recursive_get_image(const gchar* path,
 
 		if (cfg.use_file_cover && file_name) {
 			/* Look for images matching file name */
-			while((f = g_dir_read_name(d))) { 
+			while((f = g_dir_read_name(d))) {
 				gchar *newpath = g_strconcat(path, "/", f, NULL);
 
 				if (!g_file_test(newpath, G_FILE_TEST_IS_DIR) &&
@@ -148,7 +144,7 @@ fileinfo_recursive_get_image(const gchar* path,
 			}
 			g_dir_rewind(d);
 		}
-		
+
 		/* Search for files using filter */
 		while ((f = g_dir_read_name(d))) {
 			gchar *newpath = g_strconcat(path, "/", f, NULL);
@@ -173,7 +169,7 @@ fileinfo_recursive_get_image(const gchar* path,
 		/* Descend into directories recursively. */
 		while ((f = g_dir_read_name(d))) {
 			gchar *newpath = g_strconcat(path, "/", f, NULL);
-			
+
 			if(g_file_test(newpath, G_FILE_TEST_IS_DIR)) {
 				gchar *tmp = fileinfo_recursive_get_image(newpath,
 					NULL, depth + 1);
@@ -192,3 +188,19 @@ fileinfo_recursive_get_image(const gchar* path,
 
 	return NULL;
 }
+
+gchar * get_associated_image_file (const gchar * filename)
+{
+    gchar * unesc = g_filename_from_uri (filename, NULL, NULL);
+    if (! unesc)
+		return NULL;
+
+    gchar * path = g_path_get_dirname (unesc);
+    gchar * base = g_path_get_basename (unesc);
+    gchar * image_file = fileinfo_recursive_get_image (path, base, 0);
+
+    g_free (unesc);
+    g_free (path);
+    g_free (base);
+    return image_file;
+}
